@@ -1,3 +1,6 @@
+import os
+import sys
+
 extensions = ['sphinx.ext.autodoc', 'jaraco.packaging.sphinx', 'rst.linker']
 
 master_doc = "index"
@@ -65,6 +68,10 @@ link_files = {
                 pattern=r'pypa/distutils#(?P<distutils>\d+)',
                 url='{GH}/pypa/distutils/issues/{distutils}',
             ),
+            dict(
+                pattern=r'pypa/distutils@(?P<distutils_commit>[\da-f]+)',
+                url='{GH}/pypa/distutils/commit/{distutils_commit}',
+            ),
             dict(
                 pattern=r'^(?m)((?P<scm_version>v?\d+(\.\d+){1,2}))\n[-=]+\n',
                 with_scm='{text}\n{rev[timestamp]:%d %b %Y}\n',
@@ -101,8 +108,7 @@ default_role = 'any'
 
 # HTML theme
 html_theme = 'furo'
-html_logo = "images/logo.png"
-html_favicon = "images/favicon.ico"
+html_logo = "images/logo.svg"
 
 html_theme_options = {
     "sidebar_hide_name": True,
@@ -172,4 +178,27 @@ towncrier_draft_include_empty = False
 
 extensions += ['jaraco.tidelift']
 
+# Add icons (aka "favicons") to documentation
+sys.path.append(os.path.join(os.path.dirname(__file__), '_ext'))
+extensions += ['_custom_icons']
+
+# List of dicts with <link> HTML attributes
+# as defined in https://developer.mozilla.org/en-US/docs/Web/HTML/Element/link
+# except that ``file`` gets replaced with the correct ``href``
+icons = [
+    {  # "Catch-all" goes first, otherwise some browsers will overwrite
+        "rel": "icon",
+        "type": "image/svg+xml",
+        "file": "images/logo-symbol-only.svg",
+        "sizes": "any"
+    },
+    {  # Version with thicker strokes for better visibility at smaller sizes
+        "rel": "icon",
+        "type": "image/svg+xml",
+        "file": "images/favicon.svg",
+        "sizes": "16x16 24x24 32x32 48x48"
+    },
+    # rel="apple-touch-icon" does not support SVG yet
+]
+
 intersphinx_mapping['pip'] = 'https://pip.pypa.io/en/latest', None
